.. _getting_started:

===============
Getting started
===============

* :ref:`ref_installation`: Get ready to use and develop PyFluent.

* :ref:`ref_user_guide`: Learn the basics of using PyFluent.

* `Examples <https://fluent.docs.pyansys.com/version/stable/examples/index.html>`_: Explore real PyFluent use cases.

* :ref:`ref_api`: Navigate the Python API's classes and functions.

.. toctree::
   :hidden:
   :maxdepth: 2

   installation
   faqs

